@@ -1,9 +1,9 @@
 package Perinci::Sub::To::POD;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-05-24'; # DATE
+our $DATE = '2021-05-31'; # DATE
 our $DIST = 'Perinci-To-Doc'; # DIST
-our $VERSION = '0.877'; # VERSION
+our $VERSION = '0.878'; # VERSION
 
 use 5.010001;
 use Log::ger;
@@ -143,6 +143,7 @@ sub after_gen_doc {
             # no argv or args, skip, probably not perl example
             next EXAMPLE;
         }
+        $argsdump =~ s/\A\s+// if $argsdump !~ /\R/;
         my $example_code = join(
             "",
             $dres->{name}, "(",
@@ -446,7 +447,7 @@ Perinci::Sub::To::POD - Generate POD documentation from Rinci function metadata
 
 =head1 VERSION
 
-This document describes version 0.877 of Perinci::Sub::To::POD (from Perl distribution Perinci-To-Doc), released on 2021-05-24.
+This document describes version 0.878 of Perinci::Sub::To::POD (from Perl distribution Perinci-To-Doc), released on 2021-05-31.
 
 =head1 SYNOPSIS
 
@@ -468,7 +469,7 @@ Source repository is at L<https://github.com/perlancar/perl-Perinci-To-Doc>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Perinci-To-Doc/issues>
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-To-Doc>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
